# helga-isup

Helga plugin to check down for everyone or just me

## License

Copyright (c) 2013 Shaun Duncan

Licensed under the [GPL](https://github.com/shaunduncan/helga-isup/blob/master/LICENSE).
